ziggy.GraphReduce.hadoop_config

Package ziggy :: Package GraphReduce :: Module hadoop_config |
[hide private]
[frames] | no frames]

# Module hadoop_config

source code

Created on May 17, 2010 Generic configuration parameters for Hadoop-based python modules

Author: dwmclary

Variables | [hide private]
| hadoop_home = ``'``/usr/local/hadoop/``'``
| hadoop = ``'``/usr/local/hadoop/bin/hadoop``'``
| hadoop_streaming = ``'``/usr/local/hadoop/contrib/streaming/hadoop``...``
| num_map_tasks = `20`
| GraphReduce_location = ``'``/home/staff/dwmclary/workspace/GraphRe``...``
| __package__ = `None`

Variables Details | [hide private]

  ### hadoop_streaming Value:
      '/usr/local/hadoop/contrib/streaming/hadoop-0.20.2-streaming.jar'

  ### GraphReduce_location Value:
      '/home/staff/dwmclary/workspace/GraphReduce/src/GraphReduce/'